# Installation guide

This repository contains the developed architectures in the research of attention mechanisms as feature selectors.

Currently, not all architectures are available. This packages will be updated in the future (I hope that).

The code here is developed as a python package. Anyway, a magic makefile is included (for your comfort :wink:), and some specifications are included below.


## Installing from PyPi

By running the next line you will install it from PyPi repo:

```
pip install ndsl-attn-fs-archs 
```

## Installing from source

### Building the package

To build the package you just need to run:

```
make
```

or: 

```
make build
```

### Installing the package

To install the package just execute:

```
make install
```

## Running tests

To run the included tests just execute

```
make test
```

If you want to add more tests don't forget to add them in the makefile.

Easy, right? :sunglasses: 








